// Craig S. Kaplan
// A demonstration of the value of using a random seed.
// Draw a pile of circles, each with a random location, a
// random size, a random stroke, and a random fill.  That's
// eleven random numbers per circle.  That would be a huge
// hassle to keep track of by keeping track of explicit
// Circle objects (say, by creating a class to hold all of
// that data).  But by setting a random seed, we can just
// regenerate all the random numbers that went into drawing
// the circles in the previous frame.  To really get the full
// benefit here, use a slider to control the number of circles
// drawn.

import controlP5.*;

ControlP5 ui;
Slider pts;
int seed = 395345;

void setup()
{
  size( 500, 500 );

  ui = new ControlP5( this );
  pts = ui.addSlider( "Number" )
    .setRange( 1, 1000 )
    .setSize( 400, 20 )
    .setPosition( 50, 10 )
    .setDecimalPrecision( 0 );
}

void draw()
{
  randomSeed( seed );
  background( 50 );

  int num = int( pts.getValue() );

  while ( num > 0 ) {
    float r = random( 5, 100 );
    float x = random( width );
    float y = random( height );

    if ( (dist( width/2,height/2,x,y )+r) < (width/2) ) {
      fill( random(255), random(255), random(255), 
        random(255) );
      stroke( random(255), random(255), random(255), 
        random(255) );
      ellipse( x, y, r, r );
      --num;
    }
  }
}

void keyPressed()
{
  ++seed;
}