// Craig S. Kaplan
// 
// This sketch demonstrates the way a typical pseudorandom number
// generator might work under the hood.  You *absolutely* do not
// need to understand the math here for this course, and you can
// ignore this sketch if you're not interested.  I'm including
// it in case anybody wants to study he mechanics of PRNGs,
// so that they're not a complete mystery.  See
//
// https://en.wikipedia.org/wiki/Linear_congruential_generator
//
// for more information.

// Some magic numbers courtesy of Don Knuth
int a = 8121;
int c = 28411;
int m = 134456;
int seed = 0;

int my_seed = 0;

// This bit of math is much simpler than what typical random number
// generators do today, but it uses the same principles and so it 
// can serve as a demonstration of what's happening under the hood.
int rand()
{
  seed = (a*seed + c) % m;
  return seed / 1024;
}

void setup()
{
  size( 500, 500 );
}

void draw()
{
  background( 50 );
  
  seed = my_seed;
  for( int idx = 0; idx < 20; ++idx ) {
    ellipse( 4.8*rand(), 4.8*rand(), 20, 20 );
  }
}

void keyPressed()
{
  ++my_seed;
}