// Craig S. Kaplan
//
// A demonstration of combining recursion and randomness.  Not
// something discussed in class, but kind of fun so I'm throwing
// it in.
//
// Randomly and recursively subdivide rectangles into smaller
// rectangles, to get an interesting arrangement of random
// panels, inspired by the surfaces of Star Wars spaceships.

void setup()
{
  size( 600, 400 );
  background( 255 );
  makePanels( 7, 0, 0, width, height, color( #80d080 ) );
}

float perturb( float v, float range )
{
  return constrain( v + random(-range, range), 0, 255 );
}

color perturb( color c, float range )
{
  return color( perturb( red(c), range ), 
    perturb( green(c), range ), perturb( blue(c), range ) );
}

void makePanels( int levs, 
  float xmin, float ymin, float xmax, float ymax, color c )
{
  color c1 = perturb( c, pow(2, levs) );
  color c2 = perturb( c, pow(2, levs) );

  if ( levs == 0 ) {
    fill( c1 );
    rect( xmin, ymin, xmax-xmin, ymax-ymin );
  } else {
    boolean horiz = true;
    if ( (ymax-ymin) > (xmax-xmin) ) {
      horiz = false;
    }

    float t = random(0.2, 0.8);
    if ( horiz ) {
      float xdiv = lerp( xmin, xmax, t );
      makePanels( levs - 1, xmin, ymin, xdiv, ymax, c1 );
      makePanels( levs - 1, xdiv, ymin, xmax, ymax, c2 );
    } else {
      float ydiv = lerp( ymin, ymax, t );
      makePanels( levs - 1, xmin, ymin, xmax, ydiv, c1 );
      makePanels( levs - 1, xmin, ydiv, xmax, ymax, c2 );
    }
  }
}

void draw()
{
}

void keyPressed()
{
  makePanels( 7, 0, 0, width, height, color( #80d080 ) );
}