// Craig S. Kaplan
//
// A version of the 10 Print sketch that allows you to 
// adjust a bias slider dynamically without exploding
// into a riot of randomness.  This is the *bad* solution,
// where we keep an explicit array of random numbers that
// we can "replay" each frame.  The *real* way to solve
// this problem is to use the randomSeed() function, of
// course.

float bias;

import controlP5.*;

ControlP5 ui;
Slider slider;

// An array of random numbers mapped to each cell in the grid.
float[] tosses;

void setup()
{
  size( 800, 800 );
  bias = 0.5;

  ui = new ControlP5( this );
  slider = ui.addSlider( "Bias" )
    .setSize( 200, 30 )
    .setPosition( 10, 10 )
    .setRange( 0, 1 )
    .setValue( 0.5 );

  makeRandomNumbers();
}

void makeRandomNumbers()
{
  // Create a new array of 400 random numbers,
  // one per cell in the 20x20 grid we'll be 
  // drawing.
  tosses = new float[ 400 ];
  for ( int idx = 0; idx < 400; ++idx ) {
    tosses[idx] = random( 1  );
  }
}

void draw()
{
  background( 255 );
  strokeWeight( 15 );
  noFill();

  for ( int row = 0; row < 20; ++row ) {
    for ( int col = 0; col < 20; ++col ) {
      float x = col * 40;
      float y = row * 40;

      // "Play back" the array of random numbers
      // we generated previously.
      if ( tosses[ 20 * row + col ] < bias ) {
        // Draw a line from NW to SE
        line( x, y, x + 40, y + 40 );
      } else {
        // Draw a line from NE to SW
        line( x + 40, y, x, y + 40 );
      }
    }
  }
}

void controlEvent( ControlEvent ce )
{
  if ( ce.isFrom( slider ) ) {
    bias = slider.getValue();
  }
}

void keyPressed()
{
  // If you press the space bar, go ahead and 
  // generate a new array of random numbers, thereby
  // changing the design.
  if( key == ' ' ) {
    makeRandomNumbers();
  }
}