// Craig S. Kaplan
//
// Here's the culmination of our first pass at the 10 Print
// sketch -- a version based on an underlying random seed.
// Resetting the seed at the start of the frame allows us to
// regenerate the same sequence of random numbers, thus getting
// back the same design frame-to-frame without the need to store
// any explicit randomly generated numbers.  Sweet!

float bias;

import controlP5.*;

ControlP5 ui;
Slider slider;

int seed;

void setup()
{
  size( 800, 800 );
  bias = 0.5;

  ui = new ControlP5( this );
  slider = ui.addSlider( "Bias" )
    .setSize( 700, 30 )
    .setPosition( 10, 10 )
    .setRange( 0, 1 )
    .setValue( 0.5 );

  // It doesn't really matter what seed you
  // start with here.
  seed = 83567345;
}

void draw()
{
  background( 255 );
  strokeWeight( 15 );
  noFill();

  randomSeed( seed );

  for ( int row = 0; row < 20; ++row ) {
    for ( int col = 0; col < 20; ++col ) {
      float x = col * 40;
      float y = row * 40;

      if ( random(1) < bias ) {
        // Draw a line from NW to SE
        line( x, y, x + 40, y + 40 );
      } else {
        // Draw a line from NE to SW
        line( x + 40, y, x, y + 40 );
      }
    }
  }
}

void keyPressed()
{
  ++seed;
}

void controlEvent( ControlEvent ce )
{
  if ( ce.isFrom( slider ) ) {
    bias = slider.getValue();
  }
}